Moonlightning Gothenburg, Sweden March 10th 2002 Sten Düring Deck Name: Mastering the unblockable loop Crypt (12 cards, min=12, max=36, avg=6.42) ------------------------------------------ 4x Anson 8 CEL PRE aus dom prince Toreador:1 1x Anneke 10 AUS CEL PRE dom justicar Toreador:1 1x François Villon 10 AUS CEL PRE chi obf pot prince Toreador:2 1x Fatima al-Faqadi 8 CEL OBF QUI aus for Assamite:2 1x Felicia Mostrom 5 AUS CEL pre Toreador:1 1x Dorian Strack 4 AUS cel Toreador:1 1x Colin Flynn 3 aus cel Toreador:1 1x Isabel de Leon 3 AUS Toreador:2 1x Dieter Kleist 2 aus Toreador:1 Library (90 cards) Master (31) 2x Aching Beauty 1x Art Museum 8x Blood Doll 1x Club Zombie 1x Elysium: The Palace of Versailles 5x Fortitude 1x Information Highway 1x KRCG News Radio 1x London Evening Star, Tabloid Newspaper 3x Parthenon, The 1x Powerbase: Montreal 1x Rack, The 1x Society Hunting Ground 4x Toreador Grand Ball Action (9) 1x Entrancement 5x Fifth Tradition: Hospitality 2x Graverobbing 1x Third Tradition: Progeny Equipment (9) 5x Assault Rifle 1x IR Goggles 1x Palatial Estate 1x Pier 13, Port of Baltimore 1x Sport Bike Political Action (5) 2x Anathema 3x Parity Shift Retainer (4) 1x J. S. Simmons, Esq. 1x Mr. Winthrop 1x Resplendent Protector 1x Tasha Morgan Action Modifier (6) 6x Freak Drive Reaction (18) 1x Eagle's Sight 3x Forced Awakening 1x My Enemy's Enemy 8x Second Tradition: Domain 5x Telepathic Misdirection Combat (8) 3x Pursuit 3x Side Strike 2x Taste of Vitae